searchData={"items":[{"type":"module","title":"Zoneinfo","doc":"Elixir time zone support for your OS-supplied time zone database\n\nTell Elixir to use this as the default time zone database by running:\n\n```elixir\nCalendar.put_time_zone_database(Zoneinfo.TimeZoneDatabase)\n```\n\nTime zone data is loaded from the path returned by `tzpath/0`. The default\nis to use `/usr/share/zoneinfo`, but that may be changed by setting the\n`$TZPATH` environment or adding the following to your project's `config.exs`:\n\n```elixir\nconfig :zoneinfo, tzpath: \"/custom/location\"\n```\n\nCall `time_zones/0` to get the list of supported time zones.","ref":"Zoneinfo.html"},{"type":"function","title":"Zoneinfo.get_metadata/1","doc":"Return Zoneinfo metadata on a time zone\n\nThe returned metadata is limited to what's available in the source TZif data\nfile for the time zone. It's mostly useful for verifying that time zone\ninformation is available for dates used in your application. Note that proper\ntime zone calculations depend on many things and it's possible that they'll\nwork outside of the returned ranged. However, it's also possible that a time\nzone database was built and then a law changed which invalidates a record.","ref":"Zoneinfo.html#get_metadata/1"},{"type":"function","title":"Zoneinfo.time_zones/0","doc":"Return all known time zones\n\nThis function scans the path returned by `tzpath/0` for all time zones and\nperforms a basic check on each file. It may not be fast. It will not return\nthe aliases that zoneinfo uses for backwards compatibility even though they\nmay still work.","ref":"Zoneinfo.html#time_zones/0"},{"type":"function","title":"Zoneinfo.tzpath/0","doc":"Return the path to the time zone files","ref":"Zoneinfo.html#tzpath/0"},{"type":"function","title":"Zoneinfo.valid_time_zone?/1","doc":"Return whether a time zone is valid","ref":"Zoneinfo.html#valid_time_zone?/1"},{"type":"module","title":"Zoneinfo.Meta","doc":"Metadata derived from TZif information\n\nThe metadata here is mostly useful for checking the quality of the TZif files that\nwere loaded.","ref":"Zoneinfo.Meta.html"},{"type":"type","title":"Zoneinfo.Meta.t/0","doc":"Zoneinfo.Meta contains information about one time zone\n\n* `:time_zone` - the name of the time zone\n* `:tz_string` - if a POSIX TZ string is available, this is it\n* `:earliest_record_utc` - the UTC time of the earliest time zone record\n* `:latest_record_utc` - the UTC time of the latest time zone record\n* `:record_count` -- the number of records","ref":"Zoneinfo.Meta.html#t:t/0"},{"type":"module","title":"Zoneinfo.TimeZoneDatabase","doc":"`Calendar.TimeZoneDatabase` implementation for Zoneinfo\n\nPass this module to the `DateTime` functions:\n\n    iex> DateTime.now!(\"Europe/Copenhagen\", Zoneinfo.TimeZoneDatabase)\n    #DateTime \n\nor set it as the default by calling `Calendar.put_time_zone_database/1`:\n\n    iex> Calendar.put_time_zone_database(Zoneinfo.TimeZoneDatabase)\n    iex> DateTime.now!(\"Europe/Copenhagen\")\n    #DateTime","ref":"Zoneinfo.TimeZoneDatabase.html"},{"type":"extras","title":"Zoneinfo","doc":"# Zoneinfo\n\n[![Hex version](https://img.shields.io/hexpm/v/zoneinfo.svg \"Hex version\")](https://hex.pm/packages/zoneinfo)\n[![CircleCI](https://circleci.com/gh/smartrent/zoneinfo.svg?style=svg)](https://circleci.com/gh/smartrent/zoneinfo)\n\nElixir time zone support for your OS-supplied zoneinfo files\n\nWhy Zoneinfo?\n\n* Reuse your OS-maintained time zone database (usually in `/usr/share/zoneinfo`)\n* Reduce your OTP release size by not bundling time zone data\n* Load other [TZif](https://tools.ietf.org/html/rfc8536) files\n\nWhy not Zoneinfo?\n\n* [`tzdata`](http://hex.pm/packages/tzdata) and\n  [`tz`](http://hex.pm/packages/tz) work fine for you\n* You can't rely on your OS to update time zone files and don't want to\n  implement this yourself\n* You're running on Windows (the zoneinfo database can still be installed, but\n  this is not a typical configuration)\n* You need to extrapolate time zone conversions far in the future or past.\n  Zoneinfo currently is limited to the ranges in TZif files which typically go\n  to 2038.\n* Speed is of utmost importance. Zoneinfo loads time zones on demand and caches\n  them, but it does not focus on performance like `tz`.\n\nZoneinfo is tested for consistency against the `tz` library. It's possible to\ntest against `tzdata` by modifying `@truth` in the unit tests. All libraries\nsource their information from the [IANA Time Zone\nDatabase](http://www.iana.org/time-zones)","ref":"readme.html"},{"type":"extras","title":"Installation - Zoneinfo","doc":"First, add `:zoneinfo` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:zoneinfo, \"~> 0.1.0\"}\n  ]\nend\n```\n\nNext, decide whether you want to configure Elixir to use Zoneinfo as the default\ntime zone lookup. If you do, add the following line to your `config.exs`:\n\n```elixir\nconfig :elixir, time_zone_database: Zoneinfo.TimeZoneDatabase\n```\n\nor call `Calendar.put_time_zone_database/1`:\n\n```elixir\nCalendar.put_time_zone_database(Zoneinfo.TimeZoneDatabase)\n```\n\nIt's also possible to pass `Zoneinfo.TimeZoneDatabase` to `DateTime` functions to\navoid the global configuration.\n\nThe final step is to specify the location of the time zone files. Zoneinfo looks\nat the following locations:\n\n1. The `:tzpath` key in the application environment\n2. The `TZPATH` environment variable\n3. `/usr/share/zoneinfo`\n\nSince `/usr/share/zoneinfo` is the default on Linux and OSX, you may not need to\ndo anything.\n\nTo set `:tzpath` in the application environment, add this line to your\n`config.exs`:\n\n```elixir\nconfig :zoneinfo, tzpath: \"/custom/location\"\n```","ref":"readme.html#installation"},{"type":"extras","title":"Notes and caveats - Zoneinfo","doc":"#","ref":"readme.html#notes-and-caveats"},{"type":"extras","title":"Caching - Zoneinfo","doc":"While Zoneinfo does not contain a database and therefore has no logic to pull\nupdates, it does cache data in memory for better performance. It flushes the\ncache daily so that it's possible to pick up changes to the system timezone\ndata.\n\n#","ref":"readme.html#caching"},{"type":"extras","title":"Date ranges - Zoneinfo","doc":"Zoneinfo uses the date ranges stored in the TZif data for determining time zone\ninformation. While TZif files support extrapolation of dates beyond what's\nstored, Zoneinfo currently does not use it. This means that dates far enough in\nthe future won't be calculated correctly.\n\nThe default end date from the time zone compiler,\n[zic(8)](https://data.iana.org/time-zones/tzdb/zic.8.txt), is 2038. This could,\nof course, could change and one would hope that it would be pushed farther out\nrather than reduced since the files are already pretty small.\n\nIf you're looking at creating the smallest possible time zone database for and\nembedded system, using `zic`'s `-r` flag helps significantly, but make sure that\nyou have enough buffer to avoid extrapolation.\n\n#","ref":"readme.html#date-ranges"},{"type":"extras","title":"Unit tests - Zoneinfo","doc":"The tests currently take a long time to run since they're checking a LOT of\ndates and times. If you're working on a patch, you may want to limit the date\nrange in `time_zone_database_test.exs` to 10 years or less.","ref":"readme.html#unit-tests"},{"type":"extras","title":"Acknowledgments - Zoneinfo","doc":"Both [`tz`](http://hex.pm/packages/tz) and\n[`tzdata`](http://hex.pm/packages/tzdata) were both extremely helpful in\nanswering time zone questions. Code in this library will almost certainly look\nlike it was influenced from the two libraries. Additionally, being able to\ncompare the output of Zoneinfo to the output of those libraries caught a few\nsubtle time zone handling bugs that could easily have gone unnoticed. The [IANA\ntime zone rules database comments](https://www.iana.org/time-zones) and\n[timeanddate.com](https://www.timeanddate.com/time/change/) were also extremely\nhelpful to resolve discrepancies.","ref":"readme.html#acknowledgments"},{"type":"extras","title":"License - Zoneinfo","doc":"Copyright (C) 2021 SmartRent.com, LLC\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.7 - Changelog","doc":"* Improvements\n  * Reduce chances of raising when something goes wrong getting the time zone\n    information. For example, recover if a time zone hasn't been loaded yet and\n    the cache GenServer isn't available. This fixes crashes in code that may not be\n    easy to debug when there are calendar troubles.\n  * Don't load a time zone more than once if multiple processes ask for the same\n    one at the same time.","ref":"changelog.html#v0-1-7"},{"type":"extras","title":"v0.1.6 - Changelog","doc":"* Improvements\n  * Fix warnings when building on Elixir 1.15\n  * Improve testing","ref":"changelog.html#v0-1-6"},{"type":"extras","title":"v0.1.5 - Changelog","doc":"* Improvements\n  * Fix Calendar return values when time zone queries are wrong. Thanks to\n    @LostKobrakai for this fix.","ref":"changelog.html#v0-1-5"},{"type":"extras","title":"v0.1.4 - Changelog","doc":"* Improvements\n  * Updated documentation thanks to Wojtek Mach.","ref":"changelog.html#v0-1-4"},{"type":"extras","title":"v0.1.3 - Changelog","doc":"* Improvements\n  * UTC and standard time offsets are now tested for consistency with Tz.\n    Normally you just want the overall offset from UTC and that was already\n    tested (this is what's used in the DateTime calculations). The TZif data\n    doesn't split out the offsets, but it turned out that a heuristic works\n    really well.\n  * Unit tests run quickly. Thorough tests are available via `mix test --include\n    slow`\n\n* Bug fixes\n  * Fixed UTC and standard time offsets discrepancies with Tz (and hence the IANA\n    rules database). The only known exceptions now are Paris and Monoco in the\n    mid-1940s and Morocco. See the unit tests for discussion on the differences.","ref":"changelog.html#v0-1-3"},{"type":"extras","title":"v0.1.2 - Changelog","doc":"* New features\n  * Add `Zoneinfo.get_metadata/1` to expose diagnostic information useful for\n    sanity checking date ranges available on a system","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* New features\n  * Add `Zoneinfo.valid_time_zone?/1` to quickly check if a time zone is in the\n    database","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}